from django.db import migrations


def create_default_config(apps, schema_editor):
    Config = apps.get_model("api", "Config")
    Server = apps.get_model("api", "Server")

    if not Config.objects.exists():
        default_server, created = Server.objects.get_or_create(
            server_id="01",
            defaults={"name": "Default Server", "ping": 10, "selected": True},
        )

        Config.objects.create(
            ip="192.168.0.1",
            location="Default Location",
            dns="8.8.8.8",
            gateway="192.168.0.254",
            selected_server=default_server,
            is_activated=False,
            is_connected=False,
        )


class Migration(migrations.Migration):

    dependencies = [
        ("api", "0003_config_is_activated_config_is_connected"),
    ]

    operations = [
        migrations.RunPython(create_default_config),
    ]
